
///////////////////////////////////////////////////////////////////////////
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the version 3 of the GNU General Public License //
// as published by the Free Software Foundation.                         //
//                                                                       //
// This program is distributed in the hope that it will be useful, but   //
// WITHOUT ANY WARRANTY; without even the implied warranty of            //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      //
// General Public License for more details.                              //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program. If not, see <http://www.gnu.org/licenses/>.  //
//                                                                       //
// Written by Francois Fleuret, (C) IDIAP                                //
// Contact <francois.fleuret@idiap.ch> for comments & bug reports        //
///////////////////////////////////////////////////////////////////////////

#ifndef IMAGE_H
#define IMAGE_H

#include "storable.h"
#include "rgb_image.h"
#include "misc.h"

class Image : public Storable {
protected:
  int _width, _height;
  unsigned char *_content;
public:

  inline int width() { return _width; }
  inline int height() { return _height; }

  inline unsigned char value(int x, int y) {
    if(x >= 0 && x < _width && y >= 0 && y < _height)
      return _content[x + (y * _width)];
    else
      return 0;
  }

  inline void set_value(int x, int y, unsigned char v) {
    if(x >= 0 && x < _width && y >= 0 && y < _height)
      _content[x + (y * _width)] = v;
    else abort();
  }

  Image();
  Image(int width, int height);

  virtual ~Image();

  virtual void to_rgb(RGBImage *image);

  virtual void read(istream *in);
  virtual void write(ostream *out);
};

#endif
